==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/GitLabInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface GitLabInterceptorFluent<A extends GitLabInterceptorFluent<A>> extends Fluent<A>{
  public A addToEventTypes(Integer index,String item);
  public A setToEventTypes(Integer index,String item);
  public A addToEventTypes(java.lang.String... items);
  public A addAllToEventTypes(Collection<String> items);
  public A removeFromEventTypes(java.lang.String... items);
  public A removeAllFromEventTypes(Collection<String> items);
  public List<String> getEventTypes();
  public String getEventType(Integer index);
  public String getFirstEventType();
  public String getLastEventType();
  public String getMatchingEventType(Predicate<String> predicate);
  public Boolean hasMatchingEventType(Predicate<String> predicate);
  public A withEventTypes(List<String> eventTypes);
  public A withEventTypes(java.lang.String... eventTypes);
  public Boolean hasEventTypes();
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretRef getSecretRef();
  public SecretRef buildSecretRef();
  public A withSecretRef(SecretRef secretRef);
  public Boolean hasSecretRef();
  public A withNewSecretRef(String secretKey,String secretName);
  public GitLabInterceptorFluent.SecretRefNested<A> withNewSecretRef();
  public GitLabInterceptorFluent.SecretRefNested<A> withNewSecretRefLike(SecretRef item);
  public GitLabInterceptorFluent.SecretRefNested<A> editSecretRef();
  public GitLabInterceptorFluent.SecretRefNested<A> editOrNewSecretRef();
  public GitLabInterceptorFluent.SecretRefNested<A> editOrNewSecretRefLike(SecretRef item);
  public interface SecretRefNested<N> extends Nested<N>,SecretRefFluent<GitLabInterceptorFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/GitLabInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface GitLabInterceptorFluent<A extends GitLabInterceptorFluent<A>> extends Fluent<A>{
  public A addToEventTypes(int index,String item);
  public A setToEventTypes(int index,String item);
  public A addToEventTypes(java.lang.String... items);
  public A addAllToEventTypes(Collection<String> items);
  public A removeFromEventTypes(java.lang.String... items);
  public A removeAllFromEventTypes(Collection<String> items);
  public List<String> getEventTypes();
  public String getEventType(int index);
  public String getFirstEventType();
  public String getLastEventType();
  public String getMatchingEventType(Predicate<String> predicate);
  public Boolean hasMatchingEventType(Predicate<String> predicate);
  public A withEventTypes(List<String> eventTypes);
  public A withEventTypes(java.lang.String... eventTypes);
  public Boolean hasEventTypes();
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretRef getSecretRef();
  public SecretRef buildSecretRef();
  public A withSecretRef(SecretRef secretRef);
  public Boolean hasSecretRef();
  public A withNewSecretRef(String secretKey,String secretName);
  public GitLabInterceptorFluent.SecretRefNested<A> withNewSecretRef();
  public GitLabInterceptorFluent.SecretRefNested<A> withNewSecretRefLike(SecretRef item);
  public GitLabInterceptorFluent.SecretRefNested<A> editSecretRef();
  public GitLabInterceptorFluent.SecretRefNested<A> editOrNewSecretRef();
  public GitLabInterceptorFluent.SecretRefNested<A> editOrNewSecretRefLike(SecretRef item);
  public interface SecretRefNested<N> extends Nested<N>,SecretRefFluent<GitLabInterceptorFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}
